@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, Peter Thorson. All rights reserved.
+ * Copyright (c) 2014, Peter Thorson. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -165,19 +165,19 @@ public:
      *
      * @param ec A status value
      */
-    void set_proxy(const std::string & uri, lib::error_code & ec) {
+    void set_proxy(std::string const & uri, lib::error_code & ec) {
         // TODO: return errors for illegal URIs here?
         // TODO: should https urls be illegal for the moment?
         m_proxy = uri;
-        m_proxy_data.reset(new proxy_data());
+        m_proxy_data = lib::make_shared<proxy_data>();
         ec = lib::error_code();
     }
 
     /// Set the proxy to connect through (exception)
-    void set_proxy(const std::string & uri) {
+    void set_proxy(std::string const & uri) {
         lib::error_code ec;
         set_proxy(uri,ec);
-        if (ec) { throw ec; }
+        if (ec) { throw exception(ec); }
     }
 
     /// Set the basic auth credentials to use (exception free)
@@ -193,8 +193,8 @@ public:
      *
      * @param ec A status value
      */
-    void set_proxy_basic_auth(const std::string & username, const
-        std::string & password, lib::error_code & ec)
+    void set_proxy_basic_auth(std::string const & username, std::string const &
+        password, lib::error_code & ec)
     {
         if (!m_proxy_data) {
             ec = make_error_code(websocketpp::error::invalid_state);
@@ -208,12 +208,12 @@ public:
     }
 
     /// Set the basic auth credentials to use (exception)
-    void set_proxy_basic_auth(const std::string & username, const
-        std::string & password)
+    void set_proxy_basic_auth(std::string const & username, std::string const &
+        password)
     {
         lib::error_code ec;
         set_proxy_basic_auth(username,password,ec);
-        if (ec) { throw ec; }
+        if (ec) { throw exception(ec); }
     }
 
     /// Set the proxy timeout duration (exception free)
@@ -240,7 +240,7 @@ public:
     void set_proxy_timeout(long duration) {
         lib::error_code ec;
         set_proxy_timeout(duration,ec);
-        if (ec) { throw ec; }
+        if (ec) { throw exception(ec); }
     }
 
     const std::string & get_proxy() const {
@@ -290,11 +290,9 @@ public:
      * needed.
      */
     timer_ptr set_timer(long duration, timer_handler callback) {
-        timer_ptr new_timer(
-            new boost::asio::deadline_timer(
-                *m_io_service,
-                boost::posix_time::milliseconds(duration)
-            )
+        timer_ptr new_timer = lib::make_shared<boost::asio::deadline_timer>(
+            lib::ref(*m_io_service),
+            boost::posix_time::milliseconds(duration)
         );
 
         if (config::enable_multithreading) {
@@ -323,11 +321,11 @@ public:
      *
      * TODO: candidate for protected status
      *
-     * @param t Pointer to the timer in question
+     * @param post_timer Pointer to the timer in question
      * @param callback The function to call back
      * @param ec The status code
      */
-    void handle_timer(timer_ptr t, timer_handler callback,
+    void handle_timer(timer_ptr, timer_handler callback,
         boost::system::error_code const & ec)
     {
         if (ec) {
@@ -419,7 +417,8 @@ protected:
         m_io_service = io_service;
 
         if (config::enable_multithreading) {
-            m_strand.reset(new boost::asio::strand(*io_service));
+            m_strand = lib::make_shared<boost::asio::strand>(
+                lib::ref(*io_service));
 
             m_async_read_handler = m_strand->wrap(lib::bind(
                 &type::handle_async_read, get_shared(),lib::placeholders::_1,
@@ -442,8 +441,8 @@ protected:
         if (ec) {
             // reset the handlers to break the circular reference:
             // this->handler->this
-            m_async_read_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
-            m_async_write_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
+            lib::clear_function(m_async_read_handler);
+            lib::clear_function(m_async_write_handler);
         }
 
         return ec;
@@ -502,7 +501,16 @@ protected:
         );
     }
 
-    void handle_post_init_timeout(timer_ptr post_timer, init_handler callback,
+    /// Post init timeout callback
+    /**
+     * The timer pointer is included to ensure the timer isn't destroyed until
+     * after it has expired.
+     *
+     * @param post_timer Pointer to the timer in question
+     * @param callback The function to call back
+     * @param ec The status code
+     */
+    void handle_post_init_timeout(timer_ptr, init_handler callback,
         lib::error_code const & ec)
     {
         lib::error_code ret_ec;
@@ -529,6 +537,15 @@ protected:
         callback(ret_ec);
     }
 
+    /// Post init timeout callback
+    /**
+     * The timer pointer is included to ensure the timer isn't destroyed until
+     * after it has expired.
+     *
+     * @param post_timer Pointer to the timer in question
+     * @param callback The function to call back
+     * @param ec The status code
+     */
     void handle_post_init(timer_ptr post_timer, init_handler callback,
         lib::error_code const & ec)
     {
@@ -547,7 +564,7 @@ protected:
             m_alog.write(log::alevel::devel,"asio connection handle_post_init");
         }
 
-		if (m_tcp_post_init_handler) {
+        if (m_tcp_post_init_handler) {
             m_tcp_post_init_handler(m_connection_hdl);
         }
 
@@ -693,8 +710,14 @@ protected:
         }
     }
 
+    /// Proxy read callback
+    /**
+     * @param init_handler The function to call back
+     * @param ec The status code
+     * @param bytes_transferred The number of bytes read
+     */
     void handle_proxy_read(init_handler callback,
-        boost::system::error_code const & ec, size_t bytes_transferred)
+        boost::system::error_code const & ec, size_t)
     {
         if (m_alog.static_test(log::alevel::devel)) {
             m_alog.write(log::alevel::devel,
@@ -813,8 +836,8 @@ protected:
             boost::asio::buffer(buf,len),
             boost::asio::transfer_at_least(num_bytes),
             make_custom_alloc_handler(
-            	m_read_handler_allocator,
-            	m_async_read_handler
+                m_read_handler_allocator,
+                m_async_read_handler
             )
         );
     }
@@ -845,7 +868,7 @@ protected:
         if (m_read_handler) {
             m_read_handler(tec,bytes_transferred);
             // TODO: why does this line break things?
-            //m_read_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
+            //m_read_handler = _WEBSOCKETPP_NULL_FUNCTION_;
         } else {
             // This can happen in cases where the connection is terminated while
             // the transport is waiting on a read.
@@ -862,7 +885,7 @@ protected:
             return;
         }
 
-		m_bufs.push_back(boost::asio::buffer(buf,len));
+        m_bufs.push_back(boost::asio::buffer(buf,len));
 
         m_write_handler = handler;
 
@@ -870,8 +893,8 @@ protected:
             socket_con_type::get_socket(),
             m_bufs,
             make_custom_alloc_handler(
-            	m_write_handler_allocator,
-            	m_async_write_handler
+                m_write_handler_allocator,
+                m_async_write_handler
             )
         );
     }
@@ -895,15 +918,18 @@ protected:
             socket_con_type::get_socket(),
             m_bufs,
             make_custom_alloc_handler(
-            	m_write_handler_allocator,
-            	m_async_write_handler
+                m_write_handler_allocator,
+                m_async_write_handler
             )
         );
     }
 
-    void handle_async_write(boost::system::error_code const & ec,
-        size_t bytes_transferred)
-    {
+    /// Async write callback
+    /**
+     * @param ec The status code
+     * @param bytes_transferred The number of bytes read
+     */
+    void handle_async_write(boost::system::error_code const & ec, size_t) {
         m_bufs.clear();
         lib::error_code tec;
         if (ec) {
@@ -913,7 +939,7 @@ protected:
         if (m_write_handler) {
             m_write_handler(tec);
             // TODO: why does this line break things?
-            //m_write_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
+            //m_write_handler = _WEBSOCKETPP_NULL_FUNCTION_;
         } else {
             // This can happen in cases where the connection is terminated while
             // the transport is waiting on a read.
@@ -966,15 +992,15 @@ protected:
             m_alog.write(log::alevel::devel,"asio connection async_shutdown");
         }
 
-		// Reset cached handlers now that we won't be reading or writing anymore
-		// These cached handlers store shared pointers to this connection and
-		// will leak the connection if not destroyed.
-		m_async_read_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
-		m_async_write_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
-		m_init_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
+        // Reset cached handlers now that we won't be reading or writing anymore
+        // These cached handlers store shared pointers to this connection and
+        // will leak the connection if not destroyed.
+        lib::clear_function(m_async_read_handler);
+        lib::clear_function(m_async_write_handler);
+        lib::clear_function(m_init_handler);
 
-        m_read_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
-        m_write_handler = _WEBSOCKETPP_NULLPTR_TOKEN_;
+        lib::clear_function(m_read_handler);
+        lib::clear_function(m_write_handler);
 
         timer_ptr shutdown_timer;
         shutdown_timer = set_timer(
@@ -999,8 +1025,14 @@ protected:
         );
     }
 
-    void handle_async_shutdown_timeout(timer_ptr shutdown_timer, init_handler
-        callback, lib::error_code const & ec)
+    /// Async shutdown timeout handler
+    /**
+     * @param shutdown_timer A pointer to the timer to keep it in scope
+     * @param callback The function to call back
+     * @param ec The status code
+     */
+    void handle_async_shutdown_timeout(timer_ptr, init_handler callback, 
+        lib::error_code const & ec)
     {
         lib::error_code ret_ec;
 
