@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2013, Peter Thorson. All rights reserved.
+ * Copyright (c) 2014, Peter Thorson. All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions are met:
@@ -38,8 +38,6 @@
 #include <boost/bind.hpp>
 #include <boost/system/error_code.hpp>
 
-#include <iostream>
-
 namespace websocketpp {
 namespace transport {
 namespace asio {
@@ -178,7 +176,9 @@ public:
 
         m_io_service = ptr;
         m_external_io_service = true;
-        m_acceptor.reset(new boost::asio::ip::tcp::acceptor(*m_io_service));
+        m_acceptor = lib::make_shared<boost::asio::ip::tcp::acceptor>(
+            lib::ref(*m_io_service));
+            
         m_state = READY;
         ec = lib::error_code();
     }
@@ -194,9 +194,7 @@ public:
     void init_asio(io_service_ptr ptr) {
         lib::error_code ec;
         init_asio(ptr,ec);
-        if (ec) {
-            throw ec;
-        }
+        if (ec) { throw exception(ec); }
     }
 
     /// Initialize asio transport with internal io_service (exception free)
@@ -209,7 +207,7 @@ public:
      * @param ec Set to indicate what error occurred, if any.
      */
     void init_asio(lib::error_code & ec) {
-        init_asio(new boost::asio::io_service(),ec);
+        init_asio(new boost::asio::io_service(), ec);
         m_external_io_service = false;
     }
 
@@ -291,11 +289,11 @@ public:
         m_listen_backlog = backlog;
     }
     
-    /// Sets whether or not to use the SO_REUSEADDR flag when opening a listening socket
+    /// Sets whether to use the SO_REUSEADDR flag when opening listening sockets
     /**
-     * Specifies whether or not to use the SO_REUSEADDR TCP socket option. What this flag
-     * does depends on your operating system. Please consult operating system
-     * documentation for more details.
+     * Specifies whether or not to use the SO_REUSEADDR TCP socket option. What 
+     * this flag does depends on your operating system. Please consult operating
+     * system documentation for more details.
      *
      * New values affect future calls to listen only.
      *
@@ -374,9 +372,7 @@ public:
     void listen(boost::asio::ip::tcp::endpoint const & ep) {
         lib::error_code ec;
         listen(ep,ec);
-        if (ec) {
-            throw ec;
-        }
+        if (ec) { throw exception(ec); }
     }
 
     /// Set up endpoint for listening with protocol and port (exception free)
@@ -506,9 +502,7 @@ public:
     {
         lib::error_code ec;
         listen(host,service,ec);
-        if (ec) {
-            throw ec;
-        }
+        if (ec) { throw exception(ec); }
     }
 
     /// Stop listening (exception free)
@@ -543,9 +537,7 @@ public:
     void stop_listening() {
         lib::error_code ec;
         stop_listening(ec);
-        if (ec) {
-            throw ec;
-        }
+        if (ec) { throw exception(ec); }
     }
 
     /// Check if the endpoint is listening
@@ -607,7 +599,9 @@ public:
      * @since 0.3.0
      */
     void start_perpetual() {
-        m_work.reset(new boost::asio::io_service::work(*m_io_service));
+        m_work = lib::make_shared<boost::asio::io_service::work>(
+            lib::ref(*m_io_service)
+        );
     }
 
     /// Clears the endpoint's perpetual flag, allowing it to exit when empty
@@ -635,11 +629,9 @@ public:
      * needed.
      */
     timer_ptr set_timer(long duration, timer_handler callback) {
-        timer_ptr new_timer(
-            new boost::asio::deadline_timer(
-                *m_io_service,
-                boost::posix_time::milliseconds(duration)
-            )
+        timer_ptr new_timer = lib::make_shared<boost::asio::deadline_timer>(
+            *m_io_service,
+            boost::posix_time::milliseconds(duration)
         );
 
         new_timer->async_wait(
@@ -655,7 +647,7 @@ public:
         return new_timer;
     }
 
-    /// Timer callback
+    /// Timer handler
     /**
      * The timer pointer is included to ensure the timer isn't destroyed until
      * after it has expired.
@@ -664,7 +656,7 @@ public:
      * @param callback The function to call back
      * @param ec A status code indicating an error, if any.
      */
-    void handle_timer(timer_ptr t, timer_handler callback,
+    void handle_timer(timer_ptr, timer_handler callback,
         boost::system::error_code const & ec)
     {
         if (ec) {
@@ -729,9 +721,7 @@ public:
     void async_accept(transport_con_ptr tcon, accept_handler callback) {
         lib::error_code ec;
         async_accept(tcon,callback,ec);
-        if (ec) {
-            throw ec;
-        }
+        if (ec) { throw exception(ec); }
     }
 protected:
     /// Initialize logging
@@ -775,7 +765,8 @@ protected:
 
         // Create a resolver
         if (!m_resolver) {
-            m_resolver.reset(new boost::asio::ip::tcp::resolver(*m_io_service));
+            m_resolver = lib::make_shared<boost::asio::ip::tcp::resolver>(
+                lib::ref(*m_io_service));
         }
 
         std::string proxy = tcon->get_proxy();
@@ -788,7 +779,7 @@ protected:
         } else {
             lib::error_code ec;
 
-            uri_ptr pu(new uri(proxy));
+            uri_ptr pu = lib::make_shared<uri>(proxy);
 
             if (!pu->get_valid()) {
                 cb(make_error_code(error::proxy_invalid));
@@ -854,7 +845,16 @@ protected:
         }
     }
 
-    void handle_resolve_timeout(timer_ptr dns_timer, connect_handler callback,
+    /// DNS resolution timeout handler
+    /**
+     * The timer pointer is included to ensure the timer isn't destroyed until
+     * after it has expired.
+     *
+     * @param dns_timer Pointer to the timer in question
+     * @param callback The function to call back
+     * @param ec A status code indicating an error, if any.
+     */
+    void handle_resolve_timeout(timer_ptr, connect_handler callback,
         lib::error_code const & ec)
     {
         lib::error_code ret_ec;
@@ -953,7 +953,17 @@ protected:
         }
     }
 
-    void handle_connect_timeout(transport_con_ptr tcon, timer_ptr con_timer,
+    /// Asio connect timeout handler
+    /**
+     * The timer pointer is included to ensure the timer isn't destroyed until
+     * after it has expired.
+     *
+     * @param tcon Pointer to the transport connection that is being connected
+     * @param con_timer Pointer to the timer in question
+     * @param callback The function to call back
+     * @param ec A status code indicating an error, if any.
+     */
+    void handle_connect_timeout(transport_con_ptr tcon, timer_ptr,
         connect_handler callback, lib::error_code const & ec)
     {
         lib::error_code ret_ec;
